bayespy.inference.vmp.nodes.stochastic.Stochastic.set_plotter
=============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Stochastic.set_plotter